<p align="center">
  <img src="https://raw.githubusercontent.com/BuildingEnergySimulationTools/bayesbuilding/main/logo_bayes_building.svg" alt="CorrAI" width="200"/>
</p>

[![Static Badge](https://img.shields.io/badge/version-0.1.0-orange)]
[![Static Badge](https://img.shields.io/badge/python-3.10_%7C_3.11-blue)](https://pypi.org/project/corrai/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![CI](https://github.com/BuildingEnergySimulationTools/bayesbuilding/actions/workflows/build.yaml/badge.svg)](https://github.com/BuildingEnergySimulationTools/bayesbuilding/actions)

# Bayes Building
Bayesian approach to HVAC and Building energy modeling.
